@@ -38,17 +38,8 @@ py38 = sys.version_info.major == 3 and sys.version_info.minor == 8
 class ImportVisitor(ast.NodeTransformer):
     """Map all imports outside of type-checking blocks."""
 
-    __slots__ = (
-        'cwd',
-        'exempt_imports',
-        'local_imports',
-        'remote_imports',
-        'import_names',
-        'uses',
-        'unwrapped_annotations',
-    )
-
-    def __init__(self, cwd: Path, exempt_modules: Optional[list[str]] = None) -> None:
+    def __init__(self, cwd: Path, pydantic_enabled: bool, exempt_modules: Optional[list[str]] = None) -> None:
+        self.pydantic_enabled = pydantic_enabled
         self.cwd = cwd  # we need to know the current directory to guess at which imports are remote and which are not
 
         # Import patterns we want to avoid mapping
@@ -93,7 +84,7 @@ class ImportVisitor(ast.NodeTransformer):
         # to prevent TC001 "false" positives. We need a list
         # of known assignments to check whether an ast.Constant node
         # (a string) should be ignored or counted
-        self.__all___assignments: list[ast.Name] = []
+        self.__all___assignments: list[tuple[int, int]] = []
 
     @property
     def names(self) -> set[str]:
@@ -135,8 +126,8 @@ class ImportVisitor(ast.NodeTransformer):
         if not isinstance(getattr(node, 'value', ''), str):
             return False
         return any(
-            (assignment.lineno is not None and node.lineno is not None and assignment.end_lineno is not None)
-            and (assignment.lineno <= node.lineno <= assignment.end_lineno)
+            (assignment[0] is not None and node.lineno is not None and assignment[1] is not None)
+            and (assignment[0] <= node.lineno <= assignment[1])
             for assignment in self.__all___assignments
         )
 
@@ -278,21 +269,54 @@ class ImportVisitor(ast.NodeTransformer):
 
     def visit_ClassDef(self, node: ast.ClassDef) -> ast.ClassDef:
         """Note down class names."""
+        if self.pydantic_enabled and node.bases:
+            # When pydantic support is enabled, treat any class variable
+            # annotation as being required during runtime.
+            # We need to do this, or users run the risk of guarding imports
+            # to resources that actually are required at runtime -- required
+            # because Pydantic unlike most libraries, evaluates annotations
+            # *at* runtime.
+            for element in node.body:
+                if isinstance(element, ast.AnnAssign):
+                    self.visit(element.annotation)
+
         self.class_names.add(node.name)
         self.generic_visit(node)
         return node
 
     def visit_Name(self, node: ast.Name) -> ast.Name:
         """Map names."""
-        if getattr(node, 'id', '') == '__all__':
-            self.__all___assignments.append(node)
         if self._in_type_checking_block(node):
             return node
         if hasattr(node, ATTRIBUTE_PROPERTY):
             self.uses[f'{node.id}.{getattr(node, ATTRIBUTE_PROPERTY)}'] = node
+
         self.uses[node.id] = node
         return node
 
+    def visit_Assign(self, node: ast.Assign) -> ast.Assign:
+        """
+        Map __all__ assignments.
+
+        We would do this in visit_Name, except the name attribute for the assignment's
+        target's end_lineno only spans the assignment line, not the whole assignment:
+
+
+            ^^^^^^^^ this is all the ast.target for __all__ spans
+            __all__ = [  <
+                'one',   <
+                'two',   <
+                'three'  < \
+            ]            <-- This is the node.value
+
+        So we need to look at the assign element, and inspect both the target(s) and value.
+        """
+        if len(node.targets) == 1 and getattr(node.targets[0], 'id', '') == '__all__':
+            self.__all___assignments.append((node.targets[0].lineno, node.value.end_lineno or node.targets[0].lineno))
+
+        self.generic_visit(node)
+        return node
+
     def visit_Constant(self, node: ast.Constant) -> ast.Constant:
         """Map constants."""
         if self._in_type_checking_block(node):
@@ -408,11 +432,11 @@ class TypingOnlyImportsChecker:
 
     def __init__(self, node: ast.Module, options: Optional[Namespace]) -> None:
         self.cwd = Path(os.getcwd())
-        if options and hasattr(options, 'type_checking_exempt_modules'):
-            exempt_modules = options.type_checking_exempt_modules
-        else:
-            exempt_modules = []
-        self.visitor = ImportVisitor(self.cwd, exempt_modules=exempt_modules)
+
+        exempt_modules = getattr(options, 'type_checking_exempt_modules', [])
+        pydantic_enabled = getattr(options, 'type_checking_pydantic_enabled', False)
+
+        self.visitor = ImportVisitor(self.cwd, pydantic_enabled=pydantic_enabled, exempt_modules=exempt_modules)
         self.visitor.visit(node)
 
         self.generators = [
